import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * A conformance pack is a collection of AWS Config rules and remediation actions that can be easily deployed as a single entity in an account and a region or across an entire AWS Organization.
 *
 * ## Example Usage
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const conformancePack = new aws_native.configuration.ConformancePack("conformancePack", {
 *     conformancePackName: "ConformancePackName",
 *     deliveryS3Bucket: "DeliveryS3Bucket",
 *     templateS3Uri: "s3://bucketname/prefix",
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const cloudFormationCanaryPack = new aws_native.configuration.ConformancePack("cloudFormationCanaryPack", {
 *     conformancePackName: "ConformancePackName",
 *     deliveryS3Bucket: "DeliveryS3Bucket",
 *     templateS3Uri: "s3://bucketname/prefix",
 * });
 *
 * ```
 */
export declare class ConformancePack extends pulumi.CustomResource {
    /**
     * Get an existing ConformancePack resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): ConformancePack;
    /**
     * Returns true if the given object is an instance of ConformancePack.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ConformancePack;
    /**
     * A list of ConformancePackInputParameter objects.
     */
    readonly conformancePackInputParameters: pulumi.Output<outputs.configuration.ConformancePackInputParameter[] | undefined>;
    /**
     * Name of the conformance pack which will be assigned as the unique identifier.
     */
    readonly conformancePackName: pulumi.Output<string>;
    /**
     * AWS Config stores intermediate files while processing conformance pack template.
     */
    readonly deliveryS3Bucket: pulumi.Output<string | undefined>;
    /**
     * The prefix for delivery S3 bucket.
     */
    readonly deliveryS3KeyPrefix: pulumi.Output<string | undefined>;
    /**
     * A string containing full conformance pack template body. You can only specify one of the template body or template S3Uri fields.
     */
    readonly templateBody: pulumi.Output<string | undefined>;
    /**
     * Location of file containing the template body which points to the conformance pack template that is located in an Amazon S3 bucket. You can only specify one of the template body or template S3Uri fields.
     */
    readonly templateS3Uri: pulumi.Output<string | undefined>;
    /**
     * The TemplateSSMDocumentDetails object contains the name of the SSM document and the version of the SSM document.
     */
    readonly templateSsmDocumentDetails: pulumi.Output<outputs.configuration.TemplateSsmDocumentDetailsProperties | undefined>;
    /**
     * Create a ConformancePack resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: ConformancePackArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a ConformancePack resource.
 */
export interface ConformancePackArgs {
    /**
     * A list of ConformancePackInputParameter objects.
     */
    conformancePackInputParameters?: pulumi.Input<pulumi.Input<inputs.configuration.ConformancePackInputParameterArgs>[]>;
    /**
     * Name of the conformance pack which will be assigned as the unique identifier.
     */
    conformancePackName?: pulumi.Input<string>;
    /**
     * AWS Config stores intermediate files while processing conformance pack template.
     */
    deliveryS3Bucket?: pulumi.Input<string>;
    /**
     * The prefix for delivery S3 bucket.
     */
    deliveryS3KeyPrefix?: pulumi.Input<string>;
    /**
     * A string containing full conformance pack template body. You can only specify one of the template body or template S3Uri fields.
     */
    templateBody?: pulumi.Input<string>;
    /**
     * Location of file containing the template body which points to the conformance pack template that is located in an Amazon S3 bucket. You can only specify one of the template body or template S3Uri fields.
     */
    templateS3Uri?: pulumi.Input<string>;
    /**
     * The TemplateSSMDocumentDetails object contains the name of the SSM document and the version of the SSM document.
     */
    templateSsmDocumentDetails?: pulumi.Input<inputs.configuration.TemplateSsmDocumentDetailsPropertiesArgs>;
}
